<?php
global $autocar;
$title = the_title('', '', false);
$price = floatval(get_post_meta(get_the_ID(), 'vehicle_sale_price', true));
$vehicleVideo = rwmb_meta('vehicle_video', [], get_the_ID());
$attributes = array_values(rwmb_meta('custom_attributes', [], get_the_ID()));
$images = array_values(rwmb_meta('vehicle_main_image_grid', ['size' => 'vehicle-grid-image'], get_the_ID()));
$galleries = array_values(rwmb_meta('vehicle_galleries', ['size' => 'vehicle-grid-image'], get_the_ID()));
if(sizeof($images) > 0 && sizeof($galleries) > 0){
    $galleries = array_merge($images, $galleries);
} else {
    $galleries = $images;
}

$features = rwmb_meta('vehicle_features');
$features = is_array($features) ? array_values($features) : [];


$brand = rwmb_meta( 'vehicle_brands',[], get_the_ID());
$category = rwmb_meta( 'vehicle_category',[], get_the_ID());
$condition = rwmb_meta( 'vehicle_condition',[], get_the_ID());
$year = get_post_meta(get_the_ID(), 'vehicle_manufacture_year', true);
$fuel = rwmb_meta( 'vehicle_fuel',[], get_the_ID());
$transmission = rwmb_meta( 'vehicle_transmission',[], get_the_ID());
$miles = get_post_meta(get_the_ID(), 'vehicle_miles', true);
$mileage = get_post_meta(get_the_ID(), 'vehicle_mileage', true);
?>

<div class="modal-dialog modal-lg" role="document">
    <div class="modal-content">
        <div class="modal-header">
            <h5 class="modal-title" id="carModalLabel">
                <a href="<?php echo esc_url(get_permalink()) ?>"><?php the_title(); ?></a>
            </h5>
            <p>
                <i class="fa fa-car"></i> <?php echo __('Details of', 'autocar')?> <?php the_title(); ?>
            </p>
            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                <span aria-hidden="true">&times;</span>
            </button>
        </div>
        <div class="modal-body">
            <div class="row modal-raw">
                <div class="col-lg-5 modal-left">
                    <div class="modal-left-content">
                        <div class="bs-example" data-example-id="carousel-with-captions">
                            <div class="carousel slide" id="properties-carousel" data-ride="carousel">
                                <div class="carousel-inner" role="listbox">
                                    <?php $counter = 0;?>
                                    <?php if($vehicleVideo):?>
                                        <div class="item active modalIframe">
                                            <?php echo $vehicleVideo;?>
                                        </div>
                                    <?php $counter++; endif;?>
                                    <?php
                                    foreach ($galleries as $key => $gallery):
                                        $alt = null;
                                        if (!$alt && $gallery['alt'] != '') {
                                            $alt = $gallery['alt'];
                                        } elseif (!$alt && $gallery['title'] != '') {
                                            $alt = $gallery['title'];
                                        } elseif (!$alt && $gallery['caption'] != '') {
                                            $alt = $gallery['caption'];
                                        }
                                        ?>
                                        <div class="item <?php echo esc_attr($counter == 0 ? 'active' : '')?>">
                                            <img src="<?php echo esc_url($gallery['full_url']) ?>" class="thumb-preview" alt="<?php echo esc_attr($alt); ?>">
                                        </div>
                                    <?php $counter++; endforeach;?>
                                </div>

                                <a class="control control-prev" href="#properties-carousel" role="button" data-slide="prev">
                                    <i class="fa fa-angle-left"></i>
                                </a>
                                <a class="control control-next" href="#properties-carousel" role="button" data-slide="next">
                                    <i class="fa fa-angle-right"></i>
                                </a>
                            </div>
                        </div>

                        <div class="description">
                            <h3><?php echo __('Description', 'autocar')?></h3>
                            <p><?php echo wp_html_excerpt(get_post_meta(get_the_ID(), 'vehicle_short_description', true), 200, '...')?></p>
                        </div>
                    </div>
                </div>
                <div class="col-lg-7 modal-right">
                    <div class="modal-right-content bg-white">
                        <strong class="price">
                            <?php
                            echo esc_attr($autocar['opt_default_currency']);
                            echo esc_attr(number_format($price, 2));
                            ?>
                        </strong>
                        <section>
                            <h3><?php echo __('Features', 'autocar')?></h3>
                            <div class="features">
                                <ul class="bullets">
                                    <?php $featureCount = 0; foreach ($features as $feature):?>
                                        <?php
                                        if($featureCount == 7) {
                                            break;
                                        }
                                        ?>
                                        <li><?php echo $feature->name;?></li>
                                    <?php $featureCount++; endforeach;?>
                                </ul>
                            </div>
                        </section>
                        <section>
                            <h3><?php echo __('Overview', 'autocar')?></h3>
                            <dl>
                                <dt><?php echo __('Brand', 'autocar')?></dt>
                                <dd>
                                    <?php echo esc_attr(isset($brand->name) && $brand->name ? $brand->name : 'N/A');?>
                                </dd>
                                <dt><?php echo __('Category', 'autocar')?></dt>
                                <dd>
                                    <?php echo esc_attr(isset($category->name) && $category->name ? $category->name : 'N/A');?>
                                </dd>
                                <dt><?php echo __('Condition', 'autocar')?></dt>
                                <dd>
                                    <?php echo esc_attr(isset($condition->name) && $condition->name ? $condition->name : 'N/A');?>
                                </dd>
                                <dt><?php echo __('Fuel', 'autocar')?></dt>
                                <dd>
                                    <?php echo esc_attr(isset($fuel->name) ? $fuel->name : 'N/A');?>
                                </dd>
                                <dt><?php echo __('Transmission', 'autocar')?></dt>
                                <dd>
                                    <?php echo esc_attr(isset($transmission->name) ? $transmission->name : 'N/A');?>
                                </dd>
                                <dt><?php echo __('Year', 'autocar')?></dt>
                                <dd>
                                    <?php echo esc_attr($year ? $year : 'N/A')?>
                                </dd>
                                <dt><?php echo __('Miles', 'autocar')?></dt>
                                <dd>
                                    <?php echo esc_attr($miles ? $miles . ' ' .$autocar['opt_default_mile_unit'] : 'N/A');?>
                                </dd>
                                <dt><?php echo __('Mileage', 'autocar')?></dt>
                                <dd>
                                    <?php echo esc_attr($mileage ? $mileage . ' ' . $autocar['opt_default_mileage_unit'] : 'N/A');;?>
                                </dd>
                            </dl>
                        </section>
                        <a href="<?php echo esc_url(get_permalink()) ?>" class="btn button-sm button-theme"><?php echo __('Show Details', 'autocar')?></a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>