<?php
// Displaying header
get_header();
$args = array(
    'p'         => get_the_ID(), // ID of a page, post, or custom type
    'post_type' => 'vehicles',
    'posts_per_page' => 1,
);
if(!isset($_GET['preview']) && !isset($_GET['preview_id'])){
    $args['post_status'] = array('publish');
    $args['meta_query'] = array(
        array(
            'key' => 'vehicle_status',
            'value' => 'active',
            'compare' => '=',
        ),
        array(
            'key' => 'vehicle_expiry',
            'value' => date("Y-m-d"),
            'compare' => '>=',
        )
    );
}
$vehicles = new WP_Query($args);
if($vehicles->post_count == 0){
    $vehicles->set_404();
    status_header( 404 );
    get_template_part( 404 );
    exit();
}

$vehicleTitle = get_the_ID();
$sidebarPosition = $autocar['opt_default_listing_sidebar_position'] ? $autocar['opt_default_listing_sidebar_position'] : 'Right';

// Displaying single page banner
get_template_part('elements/banner-single');
?>

<?php while ($vehicles->have_posts()): $vehicles->the_post(); ?>
    <div class="car-details-body content-area">
        <div class="container">
            <div class="row">
                <div class="col-lg-12">
                    <!-- Option bar start-->
                    <div class="option-bar heading-car mb-30 details-option-bar">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="pull-left">
                                    <h3><a href="<?php echo esc_url(get_permalink()) ?>"><?php the_title(); ?></a></h3>
                                    <p><i class="fa fa-car"></i> <?php echo esc_attr__('Details of', 'autocar');?> <?php the_title(); ?></p>
                                </div>
                                <div class="p-r single-price">

                                    <?php $oldPrice = floatval(get_post_meta(get_the_ID(), 'vehicle_previous_price', true));?>
                                    <h3 class="<?php echo esc_attr($oldPrice < 1 ? 'old-price-empty' : '')?>">
                                        <?php
                                        echo esc_attr($autocar['opt_default_currency']);
                                        $newPrice = floatval(get_post_meta(get_the_ID(), 'vehicle_sale_price', true));
                                        echo esc_attr(number_format($newPrice, 2))
                                        ?>
                                    </h3>

                                    <?php $oldPrice = floatval(get_post_meta(get_the_ID(), 'vehicle_previous_price', true));?>
                                    <?php if($oldPrice > 0) :
                                        ?>
                                        <span class="del">
                                            <del>
                                                <?php
                                                echo esc_attr($autocar['opt_default_currency']);
                                                echo esc_attr(number_format($oldPrice, 2));
                                                ?>
                                            </del>
                                        </span>
                                    <?php endif;?>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- Option bar end-->
                </div>
            </div>
            <div class="row">
                <div class="col-lg-8 col-md-8 col-sm-12 col-xs-12 <?php if ($sidebarPosition == 'Left') {echo esc_attr__('col-lg-push-4 col-md-push-4', 'autocar');} ?>">
                    <div class="car-details">

                        <?php
                        $vehicleVideo = rwmb_meta('vehicle_video', [], get_the_ID());
                        $attributes = array_values(rwmb_meta('custom_attributes', [], get_the_ID()));
                        $images = array_values(rwmb_meta('vehicle_main_image_grid', ['size' => 'vehicle-grid-image'], get_the_ID()));
                        $galleries = array_values(rwmb_meta('vehicle_galleries', ['size' => 'vehicle-grid-image'], get_the_ID()));
                        if(sizeof($images) > 0 && sizeof($galleries) > 0){
                            $galleries = array_merge($images, $galleries);
                        } else {
                            $galleries = $images;
                        }

                        $features = rwmb_meta('vehicle_features');
                        $features = is_array($features) ? array_values($features) : [];
                        ?>

                        <?php $counter = 0; if(count($galleries) > 0):?>
                            <!-- Car detail slider start-->
                            <div class="car-detail-slider simple-slider hidden-mb-30">
                                <div id="carousel-custom" class="carousel slide" data-ride="carousel">
                                    <div class="carousel-outer">
                                        <div class="carousel-inner">
                                            <?php
                                            foreach ($galleries as $key => $gallery):
                                                $alt = null;
                                                if (!$alt && $gallery['alt'] != '') {
                                                    $alt = $gallery['alt'];
                                                } elseif (!$alt && $gallery['title'] != '') {
                                                    $alt = $gallery['title'];
                                                } elseif (!$alt && $gallery['caption'] != '') {
                                                    $alt = $gallery['caption'];
                                                }
                                                ?>
                                                <div class="item <?php echo esc_attr($counter == 0 ? 'active' : '')?>">
                                                    <img src="<?php echo esc_url($gallery['full_url']) ?>" class="thumb-preview" alt="<?php echo esc_attr($alt); ?>">
                                                </div>
                                                <?php $counter++; endforeach;?>
                                        </div>

                                        <?php if(sizeof($galleries) > 1):?>
                                            <!-- Controls -->
                                            <a class="left carousel-control" href="#carousel-custom" role="button" data-slide="prev">
                                        <span class="slider-mover-left no-bg" aria-hidden="true">
                                            <i class="fa fa-angle-left"></i>
                                        </span>
                                                <span class="sr-only">Previous</span>
                                            </a>
                                            <a class="right carousel-control" href="#carousel-custom" role="button" data-slide="next">
                                        <span class="slider-mover-right no-bg" aria-hidden="true">
                                            <i class="fa fa-angle-right"></i>
                                        </span>
                                                <span class="sr-only">Next</span>
                                            </a>
                                        <?php endif;?>
                                    </div>

                                    <?php if(sizeof($galleries) > 1):?>
                                        <!-- Indicators -->
                                        <ol class="carousel-indicators thumbs visible-lg visible-md">
                                            <?php foreach ($galleries as $key => $gallery): ?>
                                                <?php
                                                $alt = null;
                                                if (!$alt && $gallery['alt'] != '') {
                                                    $alt = $gallery['alt'];
                                                } elseif (!$alt && $gallery['title'] != '') {
                                                    $alt = $gallery['title'];
                                                } elseif (!$alt && $gallery['caption'] != '') {
                                                    $alt = $gallery['caption'];
                                                }
                                                ?>
                                                <li data-target="#carousel-custom" data-slide-to="<?php echo esc_attr($key); ?>" class="<?php echo esc_attr($key == 0 ? 'active' : '') ?>">
                                                    <img src="<?php echo esc_url($gallery['url']); ?>" alt="<?php echo esc_attr($alt); ?>">
                                                </li>
                                            <?php endforeach; ?>
                                        </ol>
                                    <?php endif;?>
                                </div>
                            </div>
                            <!-- Car detail slider end-->
                            <br>
                        <?php else:?>
                            <?php $vehicleDummy = $autocar['opt_default_vehicle_image']['url'];  ?>
                            <img src='<?php echo esc_attr($vehicleDummy);?>' alt='<?php the_title(); ?>' class='img-responsive'>
                        <?php endif;?>

                        <!-- Panel box start -->
                        <div class="panel-box single-block">
                            <ul class="nav nav-tabs">
                                <li class="active"><a href="#general" data-toggle="tab" aria-expanded="true">General Information</a></li>

                                <?php if (sizeof($features) > 0): ?>
                                    <li class=""><a href="#featured" data-toggle="tab" aria-expanded="false">Features &amp; Options</a></li>
                                <?php endif; ?>

                                <?php if (sizeof($attributes) > 0 && $attributes[0]['meta_key'] != ''): ?>
                                    <li class=""><a href="#extras" data-toggle="tab" aria-expanded="false">Other Specifications</a></li>
                                <?php endif; ?>

                                <?php if($vehicleVideo):?>
                                    <li class=""><a href="#video" data-toggle="tab" aria-expanded="false">Video</a></li>
                                <?php endif; ?>
                            </ul>
                            <div class="panel with-nav-tabs panel-default">
                                <div class="panel-body">
                                    <div class="tab-content">
                                        <div class="tab-pane fade active in" id="general">
                                            <div class="general-information">
                                                <div class="general-information">
                                                    <?php echo the_content(); ?>
                                                </div>
                                            </div>
                                        </div>

                                        <?php if (sizeof($features) > 0): ?>
                                            <div class="tab-pane fade" id="featured">
                                                <div class="features-opions">
                                                    <ul>
                                                        <?php foreach ($features as $feature): ?>
                                                            <li>
                                                                <i class="fa fa-circle"></i>
                                                                <?php echo esc_attr($feature->name); ?>
                                                            </li>
                                                        <?php endforeach;; ?>
                                                    </ul>
                                                </div>
                                            </div>
                                        <?php endif; ?>

                                        <?php if (sizeof($attributes) > 0 && $attributes[0]['meta_key'] != ''): ?>
                                            <div class="tab-pane fade technical" id="extras">
                                                <div class="technical-specifications">
                                                    <ul>
                                                        <?php foreach ($attributes as $attribute): ?>
                                                            <li>
                                                                <strong><?php echo esc_attr($attribute['meta_key']);?>:</strong>
                                                                <span><?php echo esc_attr($attribute['meta_value'])?></span>
                                                            </li>
                                                        <?php endforeach;; ?>
                                                    </ul>
                                                </div>
                                            </div>
                                        <?php endif; ?>

                                        <?php if($vehicleVideo):?>
                                            <div class="tab-pane fade" id="video">
                                                <?php echo $vehicleVideo;?>
                                            </div>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <!-- Panel box end -->

                        <div class="mt-50">
                            <?php comments_template(); ?>
                        </div>

                        <div class="clearfix"></div>

                        <!-- Displaying Related Vehicles [START] -->
                        <?php
                        $enableRelatedVehicle = rwmb_meta('enable_related_vehicles', [], get_the_ID());
                        $relatedVehicles = wp_autocar_get_ralated_vehicle($vehicleTitle);
                        if(isset($relatedVehicles->posts) && sizeof($relatedVehicles->posts) > 0 && $enableRelatedVehicle == '1') :
                            ?>
                            <div class="mar-b-20 mt-70">
                                <div class="underline-heading">
                                    <h3 class="line text-left"><?php echo __('Related Vehicles', 'autocar')?></h3>
                                </div>
                                <div class="row mt-30">
                                    <?php
                                    if($relatedVehicles->post_count > 0) :
                                        while($relatedVehicles->have_posts()): $relatedVehicles->the_post();
                                            ?>
                                            <div class="col-lg-6 col-md-6 col-sm-12 col-xs-12">
                                                <?php get_template_part('elements/listing-grid') ?>
                                            </div>
                                        <?php
                                        endwhile;
                                    endif;?>
                                </div>
                            </div>
                        <?php endif;?>
                        <!-- Displaying Related Vehicles [END] -->
                    </div>
                    <!-- Content div end-->

                </div>
                <div class="col-lg-4 col-md-4 col-xs-12 <?php if ($sidebarPosition == 'Left') {echo esc_attr__('col-lg-pull-8 col-md-pull-8', 'autocar');} ?>">
                    <div class="details-sidebar pad-div sidebar-widget">
                        <!-- Car details sidebar start -->
                        <div class="car-details-sidebar hidden-xs hidden-sm single-block">
                            <h2 class="title"><?php __('Specifications', 'autocar')?></h2>
                            <ul>
                                <li>
                                    <span><?php echo esc_attr__('VIN #', 'autocar'); ?>:</span>
                                    <?php
                                    $vin = get_post_meta(get_the_ID(), 'vehicle_vin', true);
                                    echo esc_attr($vin ? $vin : 'N/A')
                                    ?>
                                </li>
                                <li>
                                    <span><?php echo esc_attr__('Brand', 'autocar'); ?>:</span>
                                    <?php
                                    $brand = rwmb_meta('vehicle_brands', [], get_the_ID());
                                    echo esc_attr(isset($brand->name) ? $brand->name : 'N/A')
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Transmission', 'autocar'); ?>:</span>
                                    <?php
                                    $transmission = rwmb_meta('vehicle_transmission', [], get_the_ID());
                                    echo esc_attr(isset($transmission->name) ? $transmission->name : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Fuel', 'autocar'); ?>:</span>
                                    <?php
                                    $fuel = rwmb_meta('vehicle_fuel', [], get_the_ID());
                                    echo esc_attr(isset($fuel->name) ? $fuel->name : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Condition', 'autocar'); ?>:</span>
                                    <?php
                                    $condition = rwmb_meta('vehicle_condition', [], get_the_ID());
                                    echo esc_attr(isset($condition->name) ? $condition->name : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Category', 'autocar'); ?>:</span>
                                    <?php
                                    $category = rwmb_meta('vehicle_category', [], get_the_ID());
                                    echo esc_attr(isset($category->name) ? $category->name : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Body Style', 'autocar'); ?>:</span>
                                    <?php
                                    $body = get_post_meta(get_the_ID(), 'vehicle_body_style', true);
                                    echo esc_attr($body ? $body : 'N/A')
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Engine', 'autocar'); ?>:</span>
                                    <?php
                                    $engine = get_post_meta(get_the_ID(), 'vehicle_engine', true);
                                    echo esc_attr($engine ? $engine : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Horse Power', 'autocar'); ?>:</span>
                                    <?php
                                    $horsePower = get_post_meta(get_the_ID(), 'vehicle_horse_power', true);
                                    echo esc_attr($horsePower ? $horsePower . ' hp' : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Drive Train', 'autocar'); ?>:</span>
                                    <?php
                                    $driveTrain = get_post_meta(get_the_ID(), 'vehicle_drive_train', true);
                                    echo esc_attr($driveTrain ? $driveTrain : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Interior color', 'autocar'); ?>:</span>
                                    <?php
                                    $interiorColor = get_post_meta(get_the_ID(), 'vehicle_interior_color', true);
                                    echo esc_attr($interiorColor ? $interiorColor : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Exterior color', 'autocar'); ?>:</span>
                                    <?php
                                    $exteriorColor = get_post_meta(get_the_ID(), 'vehicle_exterior_color', true);
                                    echo esc_attr($exteriorColor ? $exteriorColor : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Miles', 'autocar'); ?>:</span>
                                    <?php
                                    $miles = get_post_meta(get_the_ID(), 'vehicle_miles', true);
                                    echo esc_attr($miles ? $miles . ' '.$autocar['opt_default_mile_unit'] : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Mileage', 'autocar'); ?>:</span>
                                    <?php
                                    $mileage = get_post_meta(get_the_ID(), 'vehicle_mileage', true);
                                    echo esc_attr($mileage ? $mileage . ' ' . $autocar['opt_default_mileage_unit'] : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Top Speed', 'autocar'); ?>:</span>
                                    <?php
                                    $topSpeed = get_post_meta(get_the_ID(), 'vehicle_top_speed', true);
                                    echo esc_attr($topSpeed ? $topSpeed . ' ' . $autocar['opt_default_speed_unit'] : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Odometer', 'autocar'); ?>:</span>
                                    <?php
                                    $odoMeter = get_post_meta(get_the_ID(), 'vehicle_odometer', true);
                                    echo esc_attr($odoMeter ? $odoMeter . ' ' . $autocar['opt_default_speed_unit'] : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Torque', 'autocar'); ?>:</span>
                                    <?php
                                    $torque = get_post_meta(get_the_ID(), 'vehicle_torque', true);
                                    echo esc_attr($torque ? $torque : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Towing Capacity', 'autocar'); ?>:</span>
                                    <?php
                                    $towingCapacity = get_post_meta(get_the_ID(), 'vehicle_towing_capacity', true);
                                    echo esc_attr($towingCapacity ? $towingCapacity : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Doors', 'autocar'); ?>:</span>
                                    <?php
                                    $doors = get_post_meta(get_the_ID(), 'vehicle_doors', true);
                                    echo esc_attr($doors ? $doors : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Passengers', 'autocar'); ?>:</span>
                                    <?php
                                    $passengers = get_post_meta(get_the_ID(), 'vehicle_passengers', true);
                                    echo esc_attr($passengers ? $passengers : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Purpose', 'autocar'); ?>:</span>
                                    <?php
                                    $vehicleFor = get_post_meta(get_the_ID(), 'vehicle_for', true);
                                    echo esc_attr($vehicleFor ? $vehicleFor : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Stock', 'autocar'); ?>:</span>
                                    <?php
                                    $stock = get_post_meta(get_the_ID(), 'vehicle_stock', true);
                                    echo esc_attr($stock ? $stock : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Expired In', 'autocar'); ?>:</span>
                                    <?php
                                    $vehicleExpiry = get_post_meta(get_the_ID(), 'vehicle_expiry', true);
                                    echo esc_attr($vehicleExpiry ? date('M d, Y', strtotime($vehicleExpiry)) : 'N/A');
                                    ?>
                                </li>

                                <li>
                                    <span><?php echo esc_attr__('Manufacture Year', 'autocar'); ?>:</span>
                                    <?php
                                    $manufactureYear = get_post_meta(get_the_ID(), 'vehicle_manufacture_year', true);
                                    echo esc_attr($manufactureYear ? $manufactureYear : 'N/A');
                                    ?>
                                </li>
                            </ul>
                        </div>
                    </div>

                    <!-- Sidebar start-->
                    <div class="sidebar">
                        <aside class="sidebar-widget">
                            <?php get_sidebar('single-vehicle'); ?>
                        </aside>
                        <!-- end-->
                    </div>
                </div>
            </div>
        </div>
    </div>
<?php endwhile;?>

<?php wp_reset_postdata();?>
<?php get_footer(); ?>