<?php

/**
 * Class ContactUs
 */
class ContactUs extends WP_Widget
{

    /**
     * ContactUs constructor.
     */
    public function __construct()
    {
        $widget_details = array(
            'classname' => 'autocar_contact_us',
            'description' => __('Contact Us Widget', 'autocar')
        );

        parent::__construct('autocar_contact_us', __('Auto Car: Contact Us', 'autocar'), $widget_details);
    }

    /**
     * @param array $instance
     */
    public function form($instance)
    {
        $title = !empty($instance['title']) ? $instance['title'] : 'Contact Us';
        ?>
        <div class="widget_box">
            <div class="widget-field">
                <label><?php echo esc_attr__('Title', 'autocar'); ?></label>
                <input class="widefat form-control"
                       name="<?php echo esc_attr($this->get_field_name('title')); ?>"
                       placeholder="<?php echo esc_attr__('Title', 'autocar'); ?>"
                       value="<?php echo esc_attr($title); ?>"/>
            </div>
            <div class="widget-field">
                <label><?php echo esc_attr__('Short Description', 'autocar'); ?></label>
                <textarea class="widefat form-control" rows="4"
                          name="<?php echo esc_attr($this->get_field_name('short_descriptiopn')); ?>"
                          placeholder="<?php echo esc_attr__('Short Description', 'autocar'); ?>"><?php echo isset($instance['short_descriptiopn']) ? esc_attr($instance['short_descriptiopn']) : null; ?>
                </textarea>
            </div>
            <div class="widget-field">
                <label><?php echo esc_attr__('Address', 'autocar'); ?></label>
                <input class="widefat form-control"
                       name="<?php echo esc_attr($this->get_field_name('address')); ?>"
                       placeholder="<?php echo esc_attr__('Address', 'autocar'); ?>"
                       value="<?php echo isset($instance['address']) ? esc_attr($instance['address']) : null; ?>"/>
            </div>
            <div class="widget-field">
                <label><?php echo esc_attr__('Email', 'autocar'); ?></label>
                <input class="widefat form-control" name="<?php echo esc_attr($this->get_field_name('email')); ?>"
                       placeholder="<?php echo esc_attr__('Email', 'autocar'); ?>"
                       value="<?php echo isset($instance['email']) ? esc_attr($instance['email']) : null; ?>"/>
            </div>
            <div class="widget-field">
                <label><?php echo esc_attr__('Phone', 'autocar'); ?></label>
                <input class="widefat form-control"
                       name="<?php echo esc_attr($this->get_field_name('phone'), 'autocar'); ?>"
                       placeholder="<?php echo esc_attr__('Phone', 'autocar'); ?>"
                       value="<?php echo isset($instance['phone']) ? esc_attr($instance['phone']) : null; ?>"/>
            </div>
            <div class="widget-field">
                <label><?php echo esc_attr__('Fax', 'autocar'); ?></label>
                <input class="widefat form-control"
                       name="<?php echo esc_attr($this->get_field_name('fax'), 'autocar'); ?>"
                       placeholder="<?php echo esc_attr__('Fax', 'autocar'); ?>"
                       value="<?php echo isset($instance['fax']) ? esc_attr($instance['fax']) : null; ?>"/>
            </div>
        </div>
        <?php
    }

    /**
     * @param array $new_instance
     * @param array $old_instance
     * @return array
     */
    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['title'] = $new_instance['title'];
        $instance['short_descriptiopn'] = strip_tags($new_instance['short_descriptiopn']);
        $instance['address'] = $new_instance['address'];
        $instance['email'] = $new_instance['email'];
        $instance['phone'] = $new_instance['phone'];
        $instance['fax'] = $new_instance['fax'];
        return $instance;
    }

    /**
     * @param array $args
     * @param array $instance
     */
    public function widget($args, $instance)
    {
        extract($args);
        $title = $instance['title'];
        $address = $instance['address'];
        $shortDescrition = $instance['short_descriptiopn'];
        $phone = $instance['phone'];
        $email = $instance['email'];
        $fax = $instance['fax'];

        echo $before_widget; ?>
        <div class="footer-item clearfix">
            <h2 class="title"><?php echo esc_attr($title) ?></h2>
            <p>
                <?php echo esc_attr($shortDescrition); ?>
            </p>
            <ul class="personal-info">
                <?php if ($address): ?>
                    <li>
                        <i class="fa fa-map-marker"></i>
                        <?php echo esc_attr($address); ?>
                    </li>
                <?php endif; ?>

                <?php if ($email): ?>
                    <li>
                        <i class="fa fa-envelope"></i>
                        Email:<a href="mailto:<?php echo esc_attr($email); ?>"><?php echo esc_attr($email); ?></a>
                    </li>
                <?php endif; ?>

                <?php if ($phone): ?>
                    <li>
                        <i class="fa fa-phone"></i>
                        Phone: <a href="tel:<?php echo esc_attr($phone); ?>"><?php echo esc_attr($phone); ?></a>
                    </li>
                <?php endif; ?>

                <?php if ($fax): ?>
                    <li>
                        <i class="fa fa-fax"></i>
                        Fax: <?php echo esc_attr($fax); ?>
                    </li>
                <?php endif; ?>
            </ul>
        </div>
        <?php echo $after_widget;
    }
}