<?php

/**
 * Class RecentComments
 */
class RecentComments extends WP_Widget
{
    /**
     * RecentComments constructor.
     */
    public function __construct()
    {
        $widget_details = array(
            'classname' => 'recent_comments_widget',
            'description' => __('Recent Comments', 'autocar')
        );

        parent::__construct('recent_comments_widget', __('Auto Car: Recent Comments', 'autocar'), $widget_details);
    }


    /**
     * @param array $instance
     */
    public function form($instance)
    {
        $title = !empty($instance['title']) ? $instance['title'] : 'Recent Comments';
        $commentCount = !empty($instance['comment_count']) ? $instance['comment_count'] : 5;
        ?>
        <div class="widget_box">
            <div class="widget-field">
                <label><?php echo __('Title', 'autocar'); ?></label>
                <input class="widefat form-control"
                       name="<?php echo esc_attr($this->get_field_name('title')); ?>"
                       placeholder="<?php echo __('Title', 'autocar'); ?>"
                       value="<?php echo esc_attr($title); ?>"/>
            </div>

            <div class="widget-field">
                <label><?php echo __('Number of Comments to Show', 'autocar'); ?></label>
                <input class="widefat form-control"
                       name="<?php echo esc_attr($this->get_field_name('comment_count')); ?>"
                       placeholder="<?php echo __('Number of Comments to Show', 'autocar'); ?>"
                       value="<?php echo esc_attr($commentCount); ?>"/>
            </div>
        </div>
        <?php
    }

    /**
     * @param array $new_instance
     * @param array $old_instance
     * @return array
     */
    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['title'] = $new_instance['title'];
        $instance['comment_count'] = $new_instance['comment_count'];
        return $instance;
    }

    /**
     * @param array $args
     * @param array $instance
     */
    public function widget($args, $instance)
    {
        extract($args);
        $title = $instance['title'];
        $commentCount = $instance['comment_count'];
        $comments = get_comments(array('number' => $commentCount));
        echo $before_widget; ?>
        <div class="recent-comments single-block">
            <h2 class="title"><?php echo esc_attr($title) ?></h2>
            <?php if (count($comments) > 0): ?>
                <?php foreach ($comments as $comment): ?>
                    <div class="media">
                        <div class="media-left">
                            <a href="#">
                                <?php echo get_avatar($comment, $size = '70'); ?></a>
                        </div>
                        <div class="media-body">
                            <p>
                                <?php echo wp_autocar_truncate_string($comment->comment_content, 100, '...') ?>
                            </p>
                            <span>By <?php echo esc_attr($comment->comment_author); ?></span>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
        <div class="clearfix"></div>
        <?php echo $after_widget;
    }
}