<?php

/**
 * Class RecentVehicles
 */
class RecentVehicles extends WP_Widget
{
    /**
     * RecentVehicles constructor.
     */
    public function __construct()
    {
        $widget_details = array(
            'classname' => 'recent_vehicle_widget',
            'description' => __('Recent Vehicles', 'autocar')
        );

        parent::__construct('recent_vehicle_widget', __('Auto Car: Recent Vehicles', 'autocar'), $widget_details);
    }


    /**
     * @param array $instance
     */
    public function form($instance)
    {
        $title = !empty($instance['title']) ? $instance['title'] : 'Recent Vehicles';
        $vehicleCount = !empty($instance['vehicle_count']) ? $instance['vehicle_count'] : 3;
        ?>
        <div class="widget_box">
            <div class="widget-field">
                <label><?php echo __('Title', 'autocar'); ?></label>
                <input class="widefat form-control"
                       name="<?php echo esc_attr($this->get_field_name('title')); ?>"
                       placeholder="<?php echo __('Title', 'autocar'); ?>"
                       value="<?php echo esc_attr($title); ?>"/>
            </div>

            <div class="widget-field">
                <label><?php echo __('Number of Vehicles to Show', 'autocar'); ?></label>
                <input class="widefat form-control"
                       name="<?php echo esc_attr($this->get_field_name('vehicle_count')); ?>"
                       placeholder="<?php echo __('Number of Vehicles to Show', 'autocar'); ?>"
                       value="<?php echo esc_attr($vehicleCount); ?>"/>
            </div>
        </div>
        <?php
    }

    /**
     * @param array $new_instance
     * @param array $old_instance
     * @return array
     */
    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['title'] = $new_instance['title'];
        $instance['vehicle_count'] = $new_instance['vehicle_count'];
        return $instance;
    }

    /**
     * @param array $args
     * @param array $instance
     */
    public function widget($args, $instance)
    {
        extract($args);
        $title = $instance['title'];
        $vehicleCount = $instance['vehicle_count'];
        $vehicles = getActiveVehicles($args = ['posts_per_page' => $vehicleCount]);
        echo $before_widget; ?>

        <div class="recent-car recent-cars single-block">
            <h2 class="title"><?php echo esc_attr($title); ?></h2>

            <?php global $autocar;
            while ($vehicles->have_posts()): $vehicles->the_post(); ?>
                <div class="media">
                    <div <?php post_class(); ?>>
                        <div class="media-left">
                            <?php
                            $image = array_values(rwmb_meta('vehicle_main_image_grid', ['size' => 'thumbnail'], get_the_ID()));
                            $vehicleName = the_title('', '', false);
                            if (sizeof($image) > 0) {
                                $imageUrl = $image[0]['url'];
                            } else {
                                $imageUrl = $autocar['opt_default_vehicle_image']['url'];
                            }
                            ?>
                            <a href="<?php echo esc_url(get_permalink()) ?>">
                                <img class="media-object" src="<?php echo esc_url($imageUrl); ?>"
                                     alt="<?php echo esc_attr($vehicleName); ?>">
                            </a>
                        </div>
                        <div class="media-body">
                            <h3>
                                <a href="<?php echo esc_url(get_permalink()) ?>"><?php echo wp_autocar_truncate_string($vehicleName, 25, '...') ?></a>
                            </h3>
                            <span>
                                <?php echo esc_attr(date('M d, Y', strtotime(get_the_date()))) ?>
                            </span>
                            <p>
                                <?php
                                echo esc_attr($autocar['opt_default_currency']);
                                echo esc_attr(number_format(get_post_meta(get_the_ID(), 'vehicle_sale_price', true), 2));
                                ?>
                            </p>
                        </div>
                    </div>
                </div>
            <?php endwhile;
            wp_reset_postdata(); ?>
        </div>
        <div class="clearfix"></div>
        <?php echo $after_widget;
    }
}