<?php

/**
 * Class SocialMedia
 */
class SocialMedia extends WP_Widget
{
    /**
     * SocialMedia constructor.
     */
    public function __construct()
    {
        $widget_details = array(
            'classname' => 'share_widget',
            'description' => __('Social Media Widget', 'autocar')
        );

        parent::__construct('share_widget', __('Auto Car: Social Media', 'autocar'), $widget_details);
    }

    /**
     * @param array $instance
     */
    public function form($instance)
    {
        $title = !empty($instance['title']) ? $instance['title'] : 'Social Media';
        ?>
        <div class="widget_box">
            <div class="widget-field">
                <label><?php echo esc_attr__('Title', 'autocar');?></label>
                <input class="widefat form-control" name="<?php echo esc_attr($this->get_field_name('title')); ?>"
                       placeholder="<?php echo esc_attr__('Title', 'autocar');?>" value="<?php echo esc_attr($title); ?>"/>
            </div>
            <div class="widget-field">
                <label><?php echo esc_attr__('Facebook', 'autocar');?></label>
                <input class="widefat form-control" type="url" name="<?php echo esc_attr($this->get_field_name('facebook_url')); ?>"
                       placeholder="<?php echo esc_attr__('Facebook URL', 'autocar');?>" value="<?php echo isset($instance['facebook_url']) ? esc_url($instance['facebook_url']) : null; ?>"/>
            </div>
            <div class="widget-field">
                <label><?php echo esc_attr__('Twitter', 'autocar');?></label>
                <input class="widefat form-control" type="url" name="<?php echo esc_attr($this->get_field_name('twitter_url')); ?>"
                       placeholder="<?php echo esc_attr__('Twitter URL', 'autocar');?>" value="<?php echo isset($instance['twitter_url']) ? esc_url($instance['twitter_url']) : null; ?>"/>
            </div>
            <div class="widget-field">
                <label><?php echo esc_attr__('Google Plus', 'autocar');?></label>
                <input class="widefat form-control" type="url" name="<?php echo esc_attr($this->get_field_name('google_plus_url')); ?>"
                       placeholder="<?php echo esc_attr__('Google Plus URL', 'autocar');?>" value="<?php echo isset($instance['google_plus_url']) ? esc_url($instance['google_plus_url']) : null; ?>"/>
            </div>
            <div class="widget-field">
                <label><?php echo esc_attr__('LinkedIn', 'autocar');?></label>
                <input class="widefat form-control" type="url" name="<?php echo esc_attr($this->get_field_name('linkedin_url')); ?>"
                       placeholder="<?php echo esc_attr__('LinkedIn URL', 'autocar');?>" value="<?php echo isset($instance['linkedin_url']) ? esc_url($instance['linkedin_url']) : null; ?>"/>
            </div>
            <div class="widget-field">
                <label><?php echo esc_attr__('Pinterest', 'autocar');?></label>
                <input class="widefat form-control" type="url" name="<?php echo esc_attr($this->get_field_name('pintrest_url')); ?>"
                       placeholder="<?php echo esc_attr__('Pinterest URL', 'autocar');?>" value="<?php echo isset($instance['pintrest_url']) ? esc_url($instance['pintrest_url']) : null; ?>"/>
            </div>
        </div>
        <?php
    }

    /**
     * @param array $new_instance
     * @param array $old_instance
     * @return array
     */
    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['title'] = $new_instance['title'];
        $instance['facebook_url'] = $new_instance['facebook_url'];
        $instance['twitter_url'] = $new_instance['twitter_url'];
        $instance['google_plus_url'] = $new_instance['google_plus_url'];
        $instance['linkedin_url'] = $new_instance['linkedin_url'];
        $instance['pintrest_url'] = $new_instance['pintrest_url'];
        return $instance;
    }

    /**
     * @param array $args
     * @param array $instance
     */
    public function widget($args, $instance)
    {
        extract($args);
        $title = $instance['title'];
        $facebook_url = $instance['facebook_url'];
        $twitter_url = $instance['twitter_url'];
        $google_plus_url = $instance['google_plus_url'];
        $linkedin_url = $instance['linkedin_url'];
        $pintrest_url = $instance['pintrest_url'];
        echo $before_widget; ?>

        <div class="social-box clearfix single-block">
            <h2 class="title"><?php echo esc_attr($title);?></h2>
            <ul class="social-list-2">
                <?php if($facebook_url):?>
                <li>
                    <a href="<?php echo esc_url($facebook_url)?>" class="facebook-bg">
                        <i class="fa fa-facebook"></i>
                    </a>
                </li>
                <?php endif;?>

                <?php if($twitter_url):?>
                    <li>
                        <a href="<?php echo esc_url($twitter_url)?>" class="twitter-bg">
                            <i class="fa fa-twitter"></i>
                        </a>
                    </li>
                <?php endif;?>


                <?php if($google_plus_url):?>
                    <li>
                        <a href="<?php echo esc_url($google_plus_url)?>" class="google-bg">
                            <i class="fa fa-google"></i>
                        </a>
                    </li>
                <?php endif;?>


                <?php if($linkedin_url):?>
                    <li>
                        <a href="<?php echo esc_url($linkedin_url)?>" class="linkedin-bg">
                            <i class="fa fa-linkedin"></i>
                        </a>
                    </li>
                <?php endif;?>


                <?php if($pintrest_url):?>
                    <li>
                        <a href="<?php echo esc_url($pintrest_url)?>" class="pinterest-bg">
                            <i class="fa fa-pinterest"></i>
                        </a>
                    </li>
                <?php endif;?>
            </ul>
        </div>
        <div class="clearfix"></div>
        <?php echo $after_widget;
    }
}