<?php

/**
 * Class VehicleTaxonomies
 */
class VehicleTaxonomies extends WP_Widget
{
    /**
     * VehicleTaxonomies constructor.
     */
    public function __construct()
    {
        $widget_details = array(
            'classname' => 'vehicle_taxonomies_widget',
            'description' => __('Vehicle Taxonomies Widget', 'autocar')
        );

        parent::__construct('vehicle_taxonomies_widget', __('Auto Car: Vehicle Taxonomies', 'autocar'), $widget_details);
    }

    /**
     * @param array $instance
     */
    public function form($instance)
    {
        $title = !empty($instance['title']) ? $instance['title'] : 'Vehicle Taxonomy';
        $iconCount = !empty($instance['icon_count']) ? $instance['icon_count'] : 10;
        $taxonomy = !empty($instance['taxonomy']) ? $instance['icon_count'] : false;
        ?>
        <div class="widget_box">
            <div class="widget-field">
                <label><?php echo esc_attr__('Title', 'autocar'); ?></label>
                <input class="widefat form-control" name="<?php echo esc_attr($this->get_field_name('title')); ?>"
                       placeholder="<?php echo esc_attr__('Title', 'autocar'); ?>" value="<?php echo esc_attr($title); ?>"/>
            </div>
        </div>

        <div class="widget_box">
            <div class="widget-field">
                <label><?php echo esc_attr__('Taxonomies', 'autocar'); ?></label>
                <select class="widefat form-control" name="<?php echo esc_attr($this->get_field_name('taxonomy')); ?>">
                    <option value="">Choose One</option>
                    <option value="vehicle_categories" <?php echo $taxonomy == 'vehicle_categories' ? esc_attr('selected="selected"') : null;?>>Vehicle Categories</option>
                    <option value="vehicle_brands" <?php echo $taxonomy == 'vehicle_brands' ? esc_attr('selected="selected"') : null;?>>Vehicle Brands</option>
                    <option value="vehicle_conditions" <?php echo $taxonomy == 'vehicle_conditions' ? esc_attr('selected="selected"') : null;?>>Vehicle Conditions</option>
                    <option value="vehicle_fuels" <?php echo $taxonomy == 'vehicle_fuels' ? esc_attr('selected="selected"') : null;?>>Vehicle Fuels</option>
                    <option value="vehicle_transmissions" <?php echo $taxonomy == 'vehicle_transmissions' ? esc_attr('selected="selected"') : null;?>>Vehicle Transmission</option>
                    <option value="vehicle_features" <?php echo $taxonomy == 'vehicle_features' ? esc_attr('selected="selected"') : null;?>>Vehicle Featured</option>
                </select>
            </div>
        </div>

        <div class="widget-field">
            <label><?php echo __('Number of item to Show', 'autocar'); ?></label>
            <input class="widefat form-control"
                   name="<?php echo esc_attr($this->get_field_name('icon_count')); ?>"
                   placeholder="<?php echo __('Number of item to Show', 'autocar'); ?>"
                   value="<?php echo esc_attr($iconCount); ?>"/>
        </div>
        <?php
    }

    /**
     * @param array $new_instance
     * @param array $old_instance
     * @return array
     */
    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['title'] = $new_instance['title'];
        $instance['icon_count'] = $new_instance['icon_count'];
        $instance['taxonomy'] = $new_instance['taxonomy'];
        return $instance;
    }

    /**
     * @param array $args
     * @param array $instance
     */
    public function widget($args, $instance)
    {
        extract($args);
        $title = $instance['title'];
        $count = $instance['icon_count'];
        $taxonomy = $instance['taxonomy'];
        $items = wp_autocar_taxonomy_item($taxonomy);
        $counter = 0;
        echo $before_widget; ?>
        <div class="single-block categorie">
            <h2 class="title"><?php echo esc_attr($title)?></h2>
            <?php if(sizeof($items) > 0):?>
                <ul>
                    <?php foreach ($items as $key => $value):?>
                        <li><a href="<?php echo esc_url(get_term_link(intval($key)))?>"><?php echo esc_attr($value);?></a></li>
                    <?php
                        $counter++;
                        if($counter >=  $count){
                            break;
                        }
                        ?>
                    <?php  endforeach;?>
                </ul>
            <?php endif;?>
        </div>
        <?php echo $after_widget;
    }
}